@@ -18,21 +18,19 @@ use Exception::Class ( 'LaTeX::Driver::Exception' );
 use File::Copy;                         # standard Perl class
 use File::Compare;                      # standard Perl class
 use File::Path;                         # standard Perl class
-use File::pushd;                        # temporary cwd changes
 use File::Slurp;
 use File::Spec;                         # from PathTools
 use File::Temp;
-use File::Which;
 use IO::File;                           # from IO
-use List::Util qw(pairgrep);
 use Readonly;
+use File::pushd;                        # temporary cwd changes
 use Capture::Tiny qw(capture);
 
 use Log::Any qw($log);
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = "1.2.0";
+our $VERSION = "1.3.1";
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -52,7 +50,7 @@ our @AUXILLARY_PROGS = qw(bibtex makeindex);
 our @POSTPROCESSORS  = qw(dvips dvipdfm ps2pdf pdf2ps);
 our @PROGRAM_NAMES   = (@PROCESSORS, @AUXILLARY_PROGS, @POSTPROCESSORS);
 
-our %program_path = pairgrep { $b } map { ( $_ => scalar which $_ ) } @PROGRAM_NAMES;
+our %program_path = map { ( $_ => $_ ) } @PROGRAM_NAMES;
 
 our @LOGFILE_EXTS = qw( log blg ilg );
 our @TMPFILE_EXTS = qw( aux log lot toc bbl ind idx cit cbk ibk );
@@ -819,7 +817,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-1.2.0
+1.3.1
 
 =head1 SYNOPSIS
 
